from .EmbeddingProvider import EmbeddingProvider
from typing import List
import openai
from config import config

class OpenAIEmbeddingProvider(EmbeddingProvider):

    def __init__(self):
        super().__init__()
        self.openai_api_key = config["app.openai.api_key"]
        self.openai_url = config["app.openai.url"]
        self.model = config["app.document.embeddings_model"]

    def getEmbedding(self, text: str) -> List[float]:
        """
        Returns the embedding for the given string
        """
        openai.api_key = self.openai_api_key
        openai.api_base = self.openai_url
        return openai.Embedding.create(input = [text],
                                model=self.model)['data'][0]['embedding']

    @property
    def OPENAI_API_KEY(self):
        return self.openai_api_key

    @OPENAI_API_KEY.setter
    def OPENAI_API_KEY(self, value):
        self.openai_api_key = value

    @property
    def OPENAI_URL(self):
        return self.openai_url

    @OPENAI_URL.setter
    def OPENAI_URL(self, value):
        self.openai_url = value

    @property
    def MODEL(self):
        return self.model

    @MODEL.setter
    def MODEL(self, value):
        self.model = value



