from fastapi import APIRouter, UploadFile, responses
from pydantic import BaseModel
from enum import Enum
import tempfile
import logging
from internal.documentTypes import DocumentType

from internal import documents

# set logger to debug
logging.basicConfig(level=logging.DEBUG)

router = APIRouter(
    prefix="/documents",
    tags=["documents"],
    responses={404: {"description": "Not found"}},
    )

@router.get("/")
async def read_documents():
    """
    Get all documents
    """
    pass


@router.post("/")
async def create_document(document_type: DocumentType,
                          files: list[UploadFile]):
    """
    Create a new document
    """

    tmpFiles = []
    docs = {}

    for file in files:
        logging.info(f"Uploaded file {file.filename}")

        tmp = tempfile.NamedTemporaryFile(delete=True)
        document_id = file.filename
        path = tmp.name

        # Write the file to a temporary file
        tmp.write(await file.read())
        tmp.flush()

        docs[document_id] = path

        tmpFiles.append(tmp)

    documents.loadDocumentsIntoWeaviate(document_type, docs)

    for tmp in tmpFiles:
        tmp.close()

    return {
            "documents": [ key for key in docs ]
            }

@router.put("/{document_id}")
async def update_document(document_id: str):
    """
    Update a document
    """
    pass

@router.delete("/{document_id}")
async def delete_document(document_id: str):
    """
    Delete a document
    """
    pass

@router.get("/find")
async def find_document(query: str, limit: int = 10):
    """
    Finds a document with content similar to given query
    """

    docs = documents.findSimilarDocuments(query, limit)

    response = []

    # format response
    for doc in docs:
        response.append({
            "document_id": doc.metadata["document_name"],
            "content": doc.page_content
            })
    return response




